==> mediawiki-1.12.1.tar.gz: mediawiki-1.12.1/languages/messages/MessagesEe.php <==
<?php
/** Ewe (Eʋegbe)
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Natsubee
 */

$messages = array(
# User preference toggles
'tog-hideminor'            => 'Ɣla tɔtrɔ suewo le tɔtrɔ yeyeawo me',
'tog-watchcreations'       => 'Tsɔ axa siwo gɔme medze la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdefault'         => 'Tsɔ axa siwo ŋu metrɔ asi le la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchmoves'           => 'Tsɔ axa siwo ƒe nɔƒe meɖɔli la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdeletion'        => 'Tsɔ axa siwo metutu la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-enotifwatchlistpages' => 'Ɖo du nam ne axa aɖe si ŋu nyeƒe ŋku le la trɔ',

'underline-always' => 'Ɣesiaɣi',
'underline-never'  => 'Gbeɖe',

# Dates
'sunday'        => 'Kɔsiɖagbe',
'monday'        => 'Dzoɖagbe',
'tuesday'       => 'Brãɖagbe',
'wednesday'     => 'Kuɖagbe',
'thursday'      => 'Yawoɖagbe',
'friday'        => 'Fiɖagbe',
'saturday'      => 'Memleɖagbe',
'sun'           => 'Dzo',
'mon'           => 'Dzo',
'tue'           => 'Brã',
'wed'           => 'Kuɖ',
'thu'           => 'Yaw',
'fri'           => 'Fiɖ',
'sat'           => 'Mem',
'january'       => 'Dzove',
'february'      => 'Dzodze',
'march'         => 'Tedoxe',
'april'         => 'Afɔfiɛ',
'may_long'      => 'Damɛ',
'june'          => 'Masa',
'july'          => 'Siamlɔm',
'august'        => 'Dasiamime',
'september'     => 'Anyɔnyɔ',
'october'       => 'Kele',
'november'      => 'Adeɛmekpɔxe',
'december'      => 'Dzome',
'january-gen'   => 'Dzove',
'february-gen'  => 'Dzodze',
'march-gen'     => 'Tedoxe',
'april-gen'     => 'Afɔfiɛ',
'may-gen'       => 'Damɛ',
'june-gen'      => 'Masa',
'july-gen'      => 'Siamlɔm',
'august-gen'    => 'Dasiamime',
'september-gen' => 'Anyɔnyɔ',
'october-gen'   => 'Kele',
'november-gen'  => 'Adeɛmekpɔxe',
'december-gen'  => 'Dzome',
'jan'           => 'Dzo',
'feb'           => 'Dzo',
'mar'           => 'Ted',
'apr'           => 'Afɔ',
'may'           => 'Damɛ',
'jun'           => 'Mas',
'jul'           => 'Sia',
'aug'           => 'Das',
'sep'           => 'Any',
'oct'           => 'Kel',
'nov'           => 'Ade',
'dec'           => 'Dzo',

'about'          => 'Ŋutinya',
'newwindow'      => '(eʋua fesre yeye)',
'cancel'         => 'Dzudzɔ etɔtrɔ',
'qbedit'         => 'Trɔ asi le eŋu',
'qbpageoptions'  => 'Axa sia',
'qbmyoptions'    => 'Nyeƒe axawo',
'qbspecialpages' => 'Axa tɔxewo',
'mypage'         => 'Axa nye',
'navigation'     => 'Mɔtabiala',
'and'            => 'kpakple',

'errorpagetitle'   => 'Vodada',
'returnto'         => 'Gbugbɔ yi $1.',
'help'             => 'Kpekpeɖeŋu',
'search'           => 'Dii',
'searchbutton'     => 'Dii',
'go'               => 'Yi',
'searcharticle'    => 'Yi',
'history_short'    => 'Xoxoawo',
'edit'             => 'Trɔ asi le eŋu',
'delete'           => 'Tutui',
'newpage'          => 'Axa yeye',
'talkpagelinktext' => 'Nyamedzroƒe',
'specialpage'      => 'Axa Tɔxe',
'talk'             => 'Nyamedzroƒe',
'toolbox'          => 'Dɔwɔnuɖaka',
'otherlanguages'   => 'Le gbe bubuwo me',
'jumptonavigation' => 'kuɖɔɖoɖo',
'jumptosearch'     => 'dii',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'         => '{{SITENAME}} ŋutinya',
'aboutpage'         => 'Project:Ŋutinya',
'currentevents'     => 'Nusiwo le dzɔdzɔm',
'currentevents-url' => 'Project:Nusiwo le dzɔdzɔm',
'edithelp'          => 'Kpekpeɖeŋu na etɔtrɔ',
'portal'            => 'Takpekpewɔƒe',
'portal-url'        => 'Project:Takpekpewɔƒe',
'sitesupport'       => 'Wɔ nunana',

'newmessageslink'         => 'du yeyewo',
'youhavenewmessagesmulti' => 'Du yeyewo le asiwo le $1',
'editsection'             => 'trɔ asi le eŋu',
'editold'                 => 'trɔ asi le eŋu',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Axa',
'nstab-user'      => 'Ezãla axa',
'nstab-special'   => 'Tɔxe',
'nstab-mediawiki' => 'Nuŋɔŋlɔ',

# General errors
'error'      => 'Vodada',
'viewsource' => 'Kpɔ alesi wowɔe',

# Login and logout pages
'login'              => 'Ge ɖe eme',
'userlogin'          => 'Ge ɖe eme / ŋlɔ ŋkɔ daɖi',
'logout'             => 'Do le eme',
'userlogout'         => 'Do le eme',
'nologinlink'        => 'Ŋlɔ ŋkɔ daɖi',
'createaccount'      => 'Ŋlɔ ŋkɔ daɖi',
'gotaccountlink'     => 'Ge ɖe eme',
'yourlanguage'       => 'Gbe:',
'loginlanguagelabel' => 'Gbe: $1',

# Edit pages
'watchthis'   => 'Le ŋku ɖe axa sia ŋu',
'savearticle' => 'Dzra axa sia ɖo',
'showpreview' => 'Fiae do ŋgɔ',
'showdiff'    => 'Fia tɔtrɔwo',
'previewnote' => '<strong>Wole afii fiam do ŋgɔ, wome dzrae ɖo haɖeke o!</strong>',
'editing'     => '$1 na etɔtrɔ',

# Search results
'powersearch' => 'Dii',

# Preferences page
'mypreferences' => 'Nyeƒe didiwo',

# Recent changes
'recentchanges' => 'Tɔtrɔ yeyewo',
'hist'          => 'xoxo',
'show'          => 'Fia',

# Recent changes linked
'recentchangeslinked' => 'Tɔtrɔ siwo kaa afii',

# Upload
'upload'    => 'Ɖo agbalẽ ɖa',
'uploadbtn' => 'Ɖo agbalẽ ɖa',

# Image list
'filehist-user' => 'Ezãla',

# MIME search
'mimesearch' => 'MIME dii',

# Miscellaneous special pages
'wantedpages'    => 'Axawo siwo le hahĩam',
'allpages'       => 'Axawo katã',
'shortpages'     => 'Axa kpuiwo',
'protectedpages' => 'Axawo siwo ŋu wole dzɔdzɔm',
'listusers'      => 'Ezãlawo ƒe xexlẽme',
'specialpages'   => 'Axa tɔxewo',
'newpages'       => 'Axa yeyewo',
'move'           => 'Ɖɔli eƒe nɔƒe',
'movethispage'   => 'Ɖɔli axa sia ƒe nɔƒe',

'version' => 'Tata',

# Special:Log
'specialloguserlabel' => 'Ezãla:',

# Special:Allpages
'allpagessubmit' => 'Yi',

# Watchlist
'watch'         => 'Le ŋku ɖe eŋu',
'watchthispage' => 'Le ŋku ɖe axa sia ŋu',

# Contributions
'mycontris' => 'Nyeƒe nuŋɔŋlɔwo',

# What links here
'whatlinkshere' => 'Nusiwo kaa afii ŋu',

# Move page
'movepage'    => 'Ɖɔli eƒe nɔƒe',
'movearticle' => 'Ɖɔli eƒe nɔƒe:',
'move-watch'  => 'Le ŋku ɖe axa sia ŋu',
'movepagebtn' => 'Ɖɔli eƒe nɔƒe',
'1movedto2'   => '[[$1]] wohee yi [[$2]]',

# Namespace 8 related
'allmessages' => 'Nuŋɔŋlɔwo',

# Tooltip help for the actions
'tooltip-pt-preferences'  => 'Nyeƒe didiwo',
'tooltip-pt-logout'       => 'Do le eme',
'tooltip-ca-move'         => 'Ɖɔli axa sia ƒe nɔƒe',
'tooltip-search'          => 'Dii {{SITENAME}}',
'tooltip-n-recentchanges' => 'Tɔtrɔ yeyewo le wiki sia me.',
'tooltip-n-help'          => 'Nuwo srɔ̃ƒe',
'tooltip-n-sitesupport'   => 'Kpe ɖe mía ŋu',
'tooltip-t-whatlinkshere' => 'Wiki nuŋɔŋlɔwo katã siwo ku ɖe afii ŋuti',
'tooltip-t-upload'        => 'Ɖo nutatawo kple nuƒoƒowo ɖa',
'tooltip-t-specialpages'  => 'Axa tɔxewo ƒe xexlẽme',
'tooltip-minoredit'       => 'Esia nye tɔtrɔ sue aɖe ko',

# Special:Newimages
'newimages' => 'Nutata yeyewo',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'katã',
'namespacesall' => 'katã',

);

==> mediawiki-1.13.1.tar.gz: mediawiki-1.13.1/languages/messages/MessagesEe.php <==
<?php
/** Ewe (Eʋegbe)
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Natsubee
 */

$messages = array(
# User preference toggles
'tog-hideminor'            => 'Ɣla tɔtrɔ suewo le tɔtrɔ yeyeawo me',
'tog-watchcreations'       => 'Tsɔ axa siwo gɔme medze la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdefault'         => 'Tsɔ axa siwo ŋu metrɔ asi le la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchmoves'           => 'Tsɔ axa siwo ƒe nɔƒe meɖɔli la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-watchdeletion'        => 'Tsɔ axa siwo metutu la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
'tog-enotifwatchlistpages' => 'Ɖo du nam ne axa aɖe si ŋu nyeƒe ŋku le la trɔ',

'underline-always' => 'Ɣesiaɣi',
'underline-never'  => 'Gbeɖe',

# Dates
'sunday'        => 'Kɔsiɖagbe',
'monday'        => 'Dzoɖagbe',
'tuesday'       => 'Brãɖagbe',
'wednesday'     => 'Kuɖagbe',
'thursday'      => 'Yawoɖagbe',
'friday'        => 'Fiɖagbe',
'saturday'      => 'Memleɖagbe',
'sun'           => 'Dzo',
'mon'           => 'Dzo',
'tue'           => 'Brã',
'wed'           => 'Kuɖ',
'thu'           => 'Yaw',
'fri'           => 'Fiɖ',
'sat'           => 'Mem',
'january'       => 'Dzove',
'february'      => 'Dzodze',
'march'         => 'Tedoxe',
'april'         => 'Afɔfiɛ',
'may_long'      => 'Damɛ',
'june'          => 'Masa',
'july'          => 'Siamlɔm',
'august'        => 'Dasiamime',
'september'     => 'Anyɔnyɔ',
'october'       => 'Kele',
'november'      => 'Adeɛmekpɔxe',
'december'      => 'Dzome',
'january-gen'   => 'Dzove',
'february-gen'  => 'Dzodze',
'march-gen'     => 'Tedoxe',
'april-gen'     => 'Afɔfiɛ',
'may-gen'       => 'Damɛ',
'june-gen'      => 'Masa',
'july-gen'      => 'Siamlɔm',
'august-gen'    => 'Dasiamime',
'september-gen' => 'Anyɔnyɔ',
'october-gen'   => 'Kele',
'november-gen'  => 'Adeɛmekpɔxe',
'december-gen'  => 'Dzome',
'jan'           => 'Dzo',
'feb'           => 'Dzo',
'mar'           => 'Ted',
'apr'           => 'Afɔ',
'may'           => 'Damɛ',
'jun'           => 'Mas',
'jul'           => 'Sia',
'aug'           => 'Das',
'sep'           => 'Any',
'oct'           => 'Kel',
'nov'           => 'Ade',
'dec'           => 'Dzo',

'about'          => 'Ŋutinya',
'newwindow'      => '(eʋua fesre yeye)',
'cancel'         => 'Dzudzɔ etɔtrɔ',
'qbedit'         => 'Trɔ asi le eŋu',
'qbpageoptions'  => 'Axa sia',
'qbmyoptions'    => 'Nyeƒe axawo',
'qbspecialpages' => 'Axa tɔxewo',
'mypage'         => 'Axa nye',
'navigation'     => 'Mɔtabiala',
'and'            => 'kpakple',

'errorpagetitle'   => 'Vodada',
'returnto'         => 'Gbugbɔ yi $1.',
'tagline'          => 'Tso {{SITENAME}}',
'help'             => 'Kpekpeɖeŋu',
'search'           => 'Dii',
'searchbutton'     => 'Dii',
'go'               => 'Yi',
'searcharticle'    => 'Yi',
'history_short'    => 'Xoxoawo',
'edit'             => 'Trɔ asi le eŋu',
'editthispage'     => 'Ðɔ axa sia ɖo',
'delete'           => 'Tutui',
'newpage'          => 'Axa yeye',
'talkpagelinktext' => 'Nyamedzroƒe',
'specialpage'      => 'Axa Tɔxe',
'talk'             => 'Nyamedzroƒe',
'toolbox'          => 'Dɔwɔnuɖaka',
'otherlanguages'   => 'Le gbe bubuwo me',
'jumptonavigation' => 'kuɖɔɖoɖo',
'jumptosearch'     => 'dii',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'         => '{{SITENAME}} ŋutinya',
'aboutpage'         => 'Project:Ŋutinya',
'currentevents'     => 'Nusiwo le dzɔdzɔm',
'currentevents-url' => 'Project:Nusiwo le dzɔdzɔm',
'edithelp'          => 'Kpekpeɖeŋu na etɔtrɔ',
'portal'            => 'Takpekpewɔƒe',
'portal-url'        => 'Project:Takpekpewɔƒe',

'newmessageslink'         => 'du yeyewo',
'youhavenewmessagesmulti' => 'Du yeyewo le asiwo le $1',
'editsection'             => 'trɔ asi le eŋu',
'editold'                 => 'trɔ asi le eŋu',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Axa',
'nstab-user'      => 'Ezãla axa',
'nstab-special'   => 'Tɔxe',
'nstab-mediawiki' => 'Nuŋɔŋlɔ',

# General errors
'error'      => 'Vodada',
'viewsource' => 'Kpɔ alesi wowɔe',

# Login and logout pages
'login'              => 'Ge ɖe eme',
'userlogin'          => 'Ge ɖe eme / ŋlɔ ŋkɔ daɖi',
'logout'             => 'Do le eme',
'userlogout'         => 'Do le eme',
'nologinlink'        => 'Ŋlɔ ŋkɔ daɖi',
'createaccount'      => 'Ŋlɔ ŋkɔ daɖi',
'gotaccountlink'     => 'Ge ɖe eme',
'yourlanguage'       => 'Gbe:',
'loginlanguagelabel' => 'Gbe: $1',

# Edit pages
'watchthis'   => 'Le ŋku ɖe axa sia ŋu',
'savearticle' => 'Dzra axa sia ɖo',
'showpreview' => 'Fiae do ŋgɔ',
'showdiff'    => 'Fia tɔtrɔwo',
'previewnote' => '<strong>Wole afii fiam do ŋgɔ, wome dzrae ɖo haɖeke o!</strong>',
'editing'     => '$1 na etɔtrɔ',

# Search results
'powersearch' => 'Dii',

# Preferences page
'mypreferences' => 'Nyeƒe didiwo',

# Recent changes
'recentchanges' => 'Tɔtrɔ yeyewo',
'hist'          => 'xoxo',
'show'          => 'Fia',

# Recent changes linked
'recentchangeslinked' => 'Tɔtrɔ siwo kaa afii',

# Upload
'upload'    => 'Ɖo agbalẽ ɖa',
'uploadbtn' => 'Ɖo agbalẽ ɖa',

# Image description page
'filehist-user' => 'Ezãla',

# MIME search
'mimesearch' => 'MIME dii',

# Miscellaneous special pages
'wantedpages'    => 'Axawo siwo le hahĩam',
'shortpages'     => 'Axa kpuiwo',
'protectedpages' => 'Axawo siwo ŋu wole dzɔdzɔm',
'listusers'      => 'Ezãlawo ƒe xexlẽme',
'newpages'       => 'Axa yeyewo',
'move'           => 'Ɖɔli eƒe nɔƒe',
'movethispage'   => 'Ɖɔli axa sia ƒe nɔƒe',

# Special:Log
'specialloguserlabel' => 'Ezãla:',

# Special:AllPages
'allpages'       => 'Axawo katã',
'allpagessubmit' => 'Yi',

# Watchlist
'watch'         => 'Le ŋku ɖe eŋu',
'watchthispage' => 'Le ŋku ɖe axa sia ŋu',

# Contributions
'mycontris' => 'Nyeƒe nuŋɔŋlɔwo',

# What links here
'whatlinkshere' => 'Nusiwo kaa afii ŋu',

# Move page
'move-page-legend' => 'Ɖɔli eƒe nɔƒe',
'movearticle'      => 'Ɖɔli eƒe nɔƒe:',
'move-watch'       => 'Le ŋku ɖe axa sia ŋu',
'movepagebtn'      => 'Ɖɔli eƒe nɔƒe',
'1movedto2'        => '[[$1]] wohee yi [[$2]]',

# Namespace 8 related
'allmessages' => 'Nuŋɔŋlɔwo',

# Tooltip help for the actions
'tooltip-pt-preferences'  => 'Nyeƒe didiwo',
'tooltip-pt-logout'       => 'Do le eme',
'tooltip-ca-move'         => 'Ɖɔli axa sia ƒe nɔƒe',
'tooltip-search'          => 'Dii {{SITENAME}}',
'tooltip-n-recentchanges' => 'Tɔtrɔ yeyewo le wiki sia me.',
'tooltip-n-help'          => 'Nuwo srɔ̃ƒe',
'tooltip-t-whatlinkshere' => 'Wiki nuŋɔŋlɔwo katã siwo ku ɖe afii ŋuti',
'tooltip-t-upload'        => 'Ɖo nutatawo kple nuƒoƒowo ɖa',
'tooltip-t-specialpages'  => 'Axa tɔxewo ƒe xexlẽme',
'tooltip-minoredit'       => 'Esia nye tɔtrɔ sue aɖe ko',

# Special:NewImages
'newimages' => 'Nutata yeyewo',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'katã',
'namespacesall' => 'katã',

# Special:Version
'version' => 'Tata', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Axa tɔxewo',

);
